*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Generate Placebo Test
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva   

clear all
set more off

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data/placebo files"

use ready_for_tables_placebo

* Creating variables for Main spline regressions
gen positive_CARXQ  = positive_CAR_announcer*win_lag_Q if announcer==0 
gen negative_CARXQ = (1-positive_CAR_announcer)*win_lag_Q if announcer==0
gen positive_CARXRD  = positive_CAR_announcer*RD if announcer==0 
gen negative_CARXRD = (1-positive_CAR_announcer)*RD if announcer==0
gen positive_CARXSaleg  = positive_CAR_announcer*win_lag_sales_growth if announcer==0 
gen negative_CARXSaleg = (1-positive_CAR_announcer)*win_lag_sales_growth if announcer==0
gen positive_CARXAssets  = positive_CAR_announcer*win_lag_lnat if announcer==0
gen negative_CARXAssets = (1-positive_CAR_announcer)*win_lag_lnat if announcer==0 

label var positive_CARXRD "Good news layoff $\times$ Comp. R\&D"
label var negative_CARXRD "Bad news layoff $\times$ Comp. R\&D"
label var positive_CARXSaleg "Good news layoff $\times$ Comp. Sales Growth"
label var negative_CARXSaleg "Bad news layoff $\times$ Comp. Sales Growth"
label var positive_CARXQ "Good news layoff $\times$ Comp. Q"
label var negative_CARXQ "Bad news layoff $\times$ Comp. Q"

* Setting global controls for regressions 
global controls1 win_lag_leverage win_lag_WW win_lag_z_score ///
win_lag_ROA win_lag_cash_holding ///
win_lag_lnat win_lag_age win_lag_employees  ///
win_lag_scaled_cogs win_lag_scaled_sga nseg 

********************************************************************************
* Table 6: Placebo Test
********************************************************************************
cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Results in paper"
`'
*A. Overall sample - only Q w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ $controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict==1, absorb(si1) vce(cluster si1)
	outreg  using Table6_Placebo.tex, replace ///
	keep(positive_CARXQ negative_CARXQ ) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*B. Overall sample - only R&D w/ controls
areg car_window_1_percent ///
positive_CARXRD negative_CARXRD ///
$controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict==1, absorb(si1) vce(cluster si1)
	outreg  using Table6_Placebo.tex, merge ///
	keep(positive_CARXRD negative_CARXRD ///
	) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*C. Overall sample - only Sales Growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXSaleg negative_CARXSaleg ///
$controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict==1, absorb(si1) vce(cluster si1)
	outreg  using Table6_Placebo.tex, merge ///
	keep(positive_CARXSaleg negative_CARXSaleg ///
	) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*D. Overall sample - all w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict==1, absorb(si1) vce(cluster si1)

	outreg  using Table6_Placebo.tex, merge ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

 
