*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Generate results for paper
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva   

clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.

*==============================================================
* Loading Data
*==============================================================

use ready_for_tables, clear

* Creating variables for Main spline regressions
gen positive_CARXQ  = positive_CAR_announcer*win_lag_Q if announcer==0 
gen negative_CARXQ = (1-positive_CAR_announcer)*win_lag_Q if announcer==0
gen positive_CARXRD  = positive_CAR_announcer*RD if announcer==0 
gen negative_CARXRD = (1-positive_CAR_announcer)*RD if announcer==0
gen positive_CARXSaleg  = positive_CAR_announcer*win_lag_sales_growth if announcer==0 
gen negative_CARXSaleg = (1-positive_CAR_announcer)*win_lag_sales_growth if announcer==0

label var positive_CARXRD "Good news layoff $\times$ Comp. R\&D"
label var negative_CARXRD "Bad news layoff $\times$ Comp. R\&D"
label var positive_CARXSaleg "Good news layoff $\times$ Comp. Sales Growth"
label var negative_CARXSaleg "Bad news layoff $\times$ Comp. Sales Growth"
label var positive_CARXQ "Good news layoff $\times$ Comp. Q"
label var negative_CARXQ "Bad news layoff $\times$ Comp. Q"


* Setting global controls for regressions
global controls1 win_lag_leverage win_lag_WW win_lag_z_score ///
win_lag_ROA win_lag_cash_holding ///
win_lag_lnat win_lag_age win_lag_employees  ///
win_lag_scaled_cogs win_lag_scaled_sga nseg currently_sp 


global probit_controls1 win_lag_Q RD win_lag_sales_growth ///
win_lag_ROA win_lag_cash_holding win_lag_scaled_cogs win_lag_scaled_sga ///
win_lag_leverage win_lag_WW win_lag_z_score win_lag_age nseg win_lag_lnat ///
win_lag_employees


/*
global probit_controls2 win_lag_Q RD win_lag_sales_growth ///
win_lag_ROA win_lag_cash_holding win_lag_scaled_cogs win_lag_scaled_sga ///
win_lag_leverage win_lag_WW win_lag_z_score win_lag_age nseg win_lag_lnat ///
win_lag_employees m_a restructuring plant_closing demand_slump sales ///
cost_and_profitability other market_competition efficiency no_reason

global probit_controls3 m_a restructuring plant_closing demand_slump sales ///
cost_and_profitability other market_competition efficiency no_reason
 


global re_controls win_lag_leverage win_lag_WW win_lag_z_score ///
win_lag_ROA win_lag_cash_holding ///
win_lag_lnat win_lag_age win_lag_employees ///
win_lag_scaled_cogs win_lag_scaled_sga nseg currently_sp ///
announcer_CAR_percent positive_CAR_announcer ann_win_lag_Q  ann_RD ann_win_lag_sales_growth ///
ann_win_lag_leverage ann_win_lag_ROA ann_win_lag_cash_holding ann_win_lag_lnat ann_win_lag_age ///
ann_win_lag_employees ann_win_lag_scaled_cogs ann_win_lag_scaled_sga ///
ann_nseg layoffratio 

*/

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Results in paper"
*==============================================================
* Table 1: Descriptive Statistics
*==============================================================

*** Good News Case
estpost tabstat car_window_1_percent $probit_controls1 size layoffratio if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1  & positive_CAR_announcer==1 , by(announcer)  stats(mean median sd N) col(stat) notot
esttab using "Panel_good_latest.tex", cells("mean(label(Mean) fmt(2)) p50(label(Median) fmt(2)) sd(label (St. Dev.) fmt(2)) count(label(N) fmt(0))") title("Good News")  label replace noobs

estpost ttest car_window_1_percent $probit_controls1 size layoffratio if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1  & positive_CAR_announcer==1 , by(announcer) unequal
esttab using ttest_good_latest.tex,  label replace

*** Bad News Case
estpost tabstat  car_window_1_percent $probit_controls1 size layoffratio if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1  & positive_CAR_announcer==0 , by(announcer)  stats(mean median sd N) col(stat) notot
esttab using "Panel_bad_latest.tex", cells("mean(label(Mean) fmt(2)) p50(label(Median) fmt(2)) sd(label (St. Dev.) fmt(2)) count(label(N) fmt(0))") title("Bad News")  label replace noobs

estpost ttest car_window_1_percent $probit_controls1 size layoffratio if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1  & positive_CAR_announcer==0 , by(announcer) unequal
 esttab using ttest_bad.tex,  label replace


*==============================================================
* Table 2: Tests for Average Effects 
*============================================================== 
*** Created from Eventus ***

*==============================================================
* Table 3: Abnormal Returns around Layoff announcements 
*============================================================== 
*** Created from Eventus ***

*==============================================================
* Table 4: Rivals' Stock Return reaction 
*============================================================== 

*A. Overall sample - only Q w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ $controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict_new==1, absorb(si1) vce(cluster si1)
	outreg  using Table4.tex, replace ///
	keep(positive_CARXQ negative_CARXQ ) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*B. Overall sample - only R&D w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXRD negative_CARXRD ///
$controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict_new==1, absorb(si1) vce(cluster si1)
	outreg  using Table4.tex, merge ///
	keep(positive_CARXRD negative_CARXRD ///
	) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*C. Overall sample - only Sales Growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXSaleg negative_CARXSaleg ///
$controls1 if announcer==0 & extreme==0 & ///
sample_all_restrict_new==1, absorb(si1) vce(cluster si1)
	outreg  using Table4.tex, merge ///
	keep(positive_CARXSaleg negative_CARXSaleg ///
	) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*D. Overall sample - Q, R&D, sales growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict_new==1, absorb(si1) vce(cluster si1)
	outreg  using Table4.tex, merge ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

gen value_gains = (car_window_1_percent/100)*win_lag_mkvalt if e(sample)==1


*==============================================================
* Table 5: Rivals' Stock Return reaction - Sub Samples
*============================================================== 
*A. Tech sector sub sample - Q, R&D, sales growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict_new==1 & tech == 1, absorb(si1) vce(cluster si1)
	outreg  using Table5.tex, replace ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*D. Non-Tech sector sub sample - Q, R&D, sales growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict_new==1 & tech == 0, absorb(si1) vce(cluster si1)
	outreg  using Table5.tex, merge ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)
	
*C. Low SMHHI sub sample - Q, R&D, sales growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict_new==1 & high_SMHHI == 0, absorb(si1) vce(cluster si1)
	outreg  using Table5.tex, merge ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

*D. High SMHHI sub sample - Q, R&D, sales growth w/ controls
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent ///
positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
positive_CARXSaleg negative_CARXSaleg $controls1 ///
if announcer==0 & extreme==0 & sample_all_restrict_new==1 & high_SMHHI == 1, absorb(si1) vce(cluster si1)
	outreg  using Table5.tex, merge ///
	keep(positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD ///
	positive_CARXSaleg negative_CARXSaleg) tex varlabels  se bdec(3) ///
	starlevels(10 5 1) starloc(1) addrows("Event FE", "Yes"\"Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adjusted R-squared) summdec(0 2 4)

	
*==============================================================
* Table 7: Time series difference approach
*============================================================== 	
cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"

*** Merging in data for new event windows from Eventus
keep if extreme==0 & sample_all_restrict_new==1
merge m:1 cusip_8dig announce_date using eventus_MM_sic_refa1, keep(match master)
drop _merge


*** Creating and labelling necessary variables
gen car_refa1_2_percent = car_refa1_2*100
gen car_diff_percent6 = (car_window_1_percent-car_refa1_2_percent)
 winsor2 car_diff_percent6, replace

label var car_refa1_2_percent "CAR[-5,-3]"
label var car_window_1_percent "CAR[-1,1]"
label var car_diff_percent6 "CAR[-1,1] - CAR[-5,-3]"
label var positive_CAR_announcer "\textit{I(Good News)}"
	
*** Creating indicator variable for sample	
bootstrap _b , reps(100) seed(10101) nodots: reg car_diff_percent6 positive_CAR_announcer if announcer==0 & sample_all_restrict_new==1 & extreme==0 , vce(cluster si1)
test _cons+positive_CAR_announcer=0 
gen sample_bharad_table2=e(sample) 

*** Table 7
cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Results in paper"

*A. Dependent variable is CAR[-5,-3]	
bootstrap _b , reps(100) seed(10101) nodots: reg car_refa1_2_percent positive_CAR_announcer if announcer==0 & sample_all_restrict==1 & sample_bharad_table2==1, vce(cluster si1)
	outreg using Table7.tex, replace ///
	keep(_cons positive_CAR_announcer ///
	) tex fragment varlabels  se bdec(3) ctitle("", "CAR[-5,-3]") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "No"\ "Industry Controls", "No" \ "Controls", "No") summstat(N\r2_a) ///
	summtitle(N\Adj. R$^2$) summdec(0 3)

*B. Dependent variable is CAR[-1,+1]		
bootstrap _b , reps(100) seed(10101) nodots: reg car_window_1_percent positive_CAR_announcer if announcer==0 & sample_all_restrict==1 & sample_bharad_table2==1, vce(cluster si1)
	outreg using Table7.tex, merge ///
	keep(_cons positive_CAR_announcer ///
	) tex fragment varlabels  se bdec(3) ctitle("", "CAR[-1,+1]") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "No"\ "Industry Controls", "No" \ "Controls", "No") summstat(N\r2_a) ///
	summtitle(N\Adj. R$^2$) summdec(0 3)

*C. Dependent variable is Chng in CAR = CAR[-1,+1] - CAR[-5,-3]	
bootstrap _b , reps(100) seed(10101) nodots: reg car_diff_percent6 positive_CAR_announcer if announcer==0 & sample_all_restrict==1  & sample_bharad_table2==1, vce(cluster si1)
	outreg using Table7.tex, merge ///
	keep(_cons positive_CAR_announcer ///
	) tex fragment varlabels  se bdec(3) ctitle("", "$\Delta CAR$") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "No"\ "Industry Controls", "No" \ "Controls", "No") summstat(N\r2_a) ///
	summtitle(N\Adj. R$^2$) summdec(0 3)


*==============================================================
* Table 8: Difference approach - Intensity of Treatment
*============================================================== 

*** Creating indicator variable for sample	
bootstrap _b , reps(100) seed(10101) nodots: areg car_diff_percent6 positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg $controls1 i.fyear if announcer==0 & sample_all_restrict_new==1 & extreme==0,absorb(sic_3dig) vce(cluster si1)
test _cons+positive_CAR_announcer=0
gen sample_bharad_table3=e(sample)


*A. Dependent variable is CAR[-5,-3]	with all controls included	
bootstrap _b , reps(100) seed(10101) nodots: areg car_refa1_2_percent positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg $controls1 i.fyear if announcer==0 & sample_all_restrict==1 & sample_bharad_table3==1, absorb(sic_3dig) vce(cluster si1)
outreg using Table8.tex, replace ///
	keep(_cons positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg ///
	) tex fragment varlabels  se bdec(3) ctitle("", "CAR[-5,-3]") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "Yes"\ "Industry Controls", "Yes" \ "Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adj. R$^2$) summdec(0 2 3)

*B. Dependent variable is CAR[-1,+1] with all controls included	
bootstrap _b , reps(100) seed(10101) nodots: areg car_window_1_percent positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg $controls1 i.fyear if announcer==0 & sample_all_restrict==1 & sample_bharad_table3==1,absorb(sic_3dig) vce(cluster si1)
	outreg using Table8.tex, merge ///
	keep(_cons positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg ///
	) tex fragment varlabels  se bdec(3) ctitle("", "CAR[-1,+1]") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "Yes"\ "Industry Controls", "Yes" \ "Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adj. R$^2$) summdec(0 2 3)

*C. Dependent variable is Chng in CAR = CAR[-1,+1] - CAR[-5,-3] with all controls included
bootstrap _b , reps(100) seed(10101) nodots: areg car_diff_percent6 positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg $controls1 i.fyear if announcer==0 & sample_all_restrict==1 & sample_bharad_table3==1,absorb(sic_3dig) vce(cluster si1)
	outreg using Table8.tex, merge ///
	keep(_cons positive_CAR_announcer positive_CARXQ negative_CARXQ positive_CARXRD negative_CARXRD positive_CARXSaleg negative_CARXSaleg ///
	) tex fragment varlabels  se bdec(3) ctitle("", "$\Delta CAR$") ///
	starlevels(10 5 1) starloc(1) addrows("No. of Layoffs","658" \ "Year Dummies", "Yes"\ "Industry Controls", "Yes" \ "Controls", "Yes") summstat(N\F\r2_a) ///
	summtitle(N\F statistic\Adj. R$^2$) summdec(0 2 3)	
	
	
	
