*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Generate Appendix graphs
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva   


cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.

*==============================================================
* Loading and cleaning delisting data from CRSP-COMPUSTAT
*==============================================================

clear all
set more off
use deletion.dta, clear
keep if dldte!=.

keep gvkey dlrsn dldte
duplicates drop

tempfile deletion_clean
destring gvkey, replace
save deletion_clean, replace


*==============================================================
* Setting up sample for creating operating performance trends
*==============================================================
clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.

use ready_for_tables, clear

* Keeping only necessary variables
keep if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1 
keep announcer announce_date si1 gvkey sic_3dig

* Generating pre post time variables
gen year2= year(announce_date)
gen year0 = year2-2
gen year1 = year2-1
gen year3 = year2+1
gen year4 = year2+2
gen year5 = year2+3

destring gvkey, replace

keep gvkey year0 year1 year2 year3 year4 year5
duplicates drop
order gvkey year0 year1 year2 year3 year4 year5

bysort gvkey: egen max_year = max(year5)
bysort gvkey: egen min_year = min(year0)

keep if year0==min_year

gen adjustment= max_year - year5

local i=1

while `i'<= adjustment {
local j=5+`i'
gen year`j' = year5+`i'
local i = `i'+1
}
* reshaping the data
reshape long year, i(gvkey) j(time)

drop min_year max_year
drop if year>2019

merge m:1 gvkey using deletion_clean.dta
drop if _merge==2
drop _merge

gen delisting_year=year(dldte)
drop if year>delisting_year

save operating_range, replace

/* REASONS FOR DELISTING

1	Acquisition or merger
2	Bankruptcy
3	Liquidation
4	Reverse acquisition (1983 forward)
5	No longer fits original format (1978 forward)
6	Leveraged buyout (1982 forward)
7	Other (no longer files with SEC among other possible reasons), but pricing continues
9	Now a private company
10	Other (no longer files with SEC among other reasons)
11	Agency governing settlement of securities' trading inactivated the issue's Local Settlement Code because the issue matured, expired or was called. No successor settlement code was established.
12	Agency governing settlement of securities' trading inactivated the issue's Local Settlement Code. A successor settlement code was established; issue was changed for another, as in a par value change.
13	Price source for the SEDOL was no longer available. Issue now identified under different SEDOL.
14	Fully paid issue was replaced or partly paid issue was replaced by a subsequent installment. Successor settlement code was established.
*/


*==============================================================
* creating operating performance varibales
*==============================================================
* Operating performance data from compustat
clear all
use operating_info_compustat, clear

* Merging in Market Values from Compustat
merge 1:1 gvkey datadate indfmt using mkvalt
keep if _merge==3
drop _merge
destring gvkey, replace
gen year = fyear
drop if year==.

/* there are duplicates because COMPUSTAT pulls 10-K data in industrial and financial services format for some firms */
bysort gvkey year: egen n_obs= count(year)
drop if indfmt=="FS" & n_obs>1
drop n_obs

/* Apart from that there is a couple of observations with duplicates because of canadian dollars */
bysort gvkey year: egen n_obs= count(year)
drop if n_obs==2

* Merging in range indicators for operating performance tests
merge 1:1 gvkey year using operating_range
keep if _merge==3
drop _merge

gen mkvalt1 = prcc_f*csho

gen mkvalt_final = mkvalt
replace mkvalt_final = mkvalt1 if mkvalt==.
label var mkvalt_final "Market Value - Total - Fiscal"
drop mkvalt mkvalt1 csho prcc_f

/* Creating the measures based on "Post-Issue Operating Performance of IPO Firms" by Jain and Kini, JF 1994 */

gen operational_perf1 = oibdp/at
label var operational_perf1 "oibdp/at"

gen operational_perf2 = oancf/at
label var operational_perf2 "oancf/at"

keep gvkey year dldte dlrsn mkvalt_final operational_perf1 operational_perf2
duplicates drop

save operating_compustat, replace

*==============================================================
* Merging operating performance varibales to primary data sample
*==============================================================
clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"

use ready_for_tables, clear

* Keeping only required variables

keep if announcer_sp==1 & extreme==0 & sample_all_restrict_new==1 
keep announcer announce_date si1 gvkey sic_3dig

* Re-Creating announcement groups for pre and post years 
egen new_si1=group(si1)

forvalues i=1/658 {
preserve
keep if new_si1==`i'

gen year2= year(announce_date)
gen year0 = year2-2
gen year1 = year2-1
gen year3 = year2+1
gen year4 = year2+2
gen year5 = year2+3

destring gvkey, replace
reshape long year, i(gvkey) j(time)
merge 1:1 gvkey year using operating_compustat.dta
keep if _merge==3
drop _merge

/* Delete the announcer info */
drop if announcer==1

bysort si1 time: egen total_mkvalt = total(mkvalt_final)
gen share_val = mkvalt_final/total_mkvalt

gen operat1_part1 = share_val*operational_perf1
gen operat2_part1 = share_val*operational_perf2

bysort si1 time: egen operat1_wt = total(operat1_part1)

bysort si1 time: egen operat2_wt = total(operat2_part1)


bysort si1 time: egen operat1_uw = total(operational_perf1)
bysort si1 time: egen operat2_uw = total(operational_perf2)

keep announce_date sic_3dig si1 new_si1 time year operat1_wt operat2_wt operat1_uw operat2_uw
duplicates drop

xtset si1 time

gen operat1_ret_wt = (operat1_wt-L1.operat1_wt)/L1.operat1_wt
gen operat2_ret_wt = (operat2_wt-L1.operat2_wt)/L1.operat2_wt

gen operat1_ret_uw = (operat1_uw-L1.operat1_uw)/L1.operat1_uw
gen operat2_ret_uw = (operat2_uw-L1.operat2_uw)/L1.operat2_uw


keep announce_date sic_3dig si1 new_si1 time year operat1_ret_wt operat2_ret_wt operat1_ret_uw  operat2_ret_uw
duplicates drop

tempfile si1_`i'
save si1_`i', replace
restore
}

use si1_658, replace
forvalues j=1/657 {
append using si1_`j'
}

save operating_performance_final.dta, replace

*==============================================================
* Generating graphs
*==============================================================
clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"

use ready_for_tables

keep si1 positive_CAR_announcer
duplicates drop

merge 1:m si1 using operating_performance_final.dta
keep if _merge==3
drop _merge


bysort positive_CAR_announcer time: egen Med_R_operat1_wt= median(operat1_ret_wt)
bysort positive_CAR_announcer time: egen Med_R_operat2_wt= median(operat2_ret_wt)

bysort positive_CAR_announcer time: egen Med_R_operat1_uw= median(operat1_ret_uw)
bysort positive_CAR_announcer time: egen Med_R_operat2_uw= median(operat2_ret_uw)

keep time positive_CAR_announcer Med_R_operat1_wt Med_R_operat2_wt Med_R_operat1_uw Med_R_operat2_uw
duplicates drop

keep positive_CAR_announcer time Med_R_operat1_wt
gen median_return = Med_R_operat1_wt*100
gen new_time= time-2
drop if new_time==-2

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Results in paper"

graph twoway line median_return new_time if positive_CAR_announcer==1, lwidth(thick) lpattern(solid) lcolor(gs0) ||line median_return new_time if positive_CAR_announcer==0, lwidth(thick) lpattern(solid) lcolor(gs7) graphregion(color(white)) bgcolor(white) xline(0, lwidth(medium) lpattern(dash) lcolor(gs0)) legend(lab(1 "Good News") lab (2 "Bad News") region(lcolor(white))) xtitle("Time to Announcement") ytitle("Median Op. Performance")
graph export Figure1A_Op_perf.png, replace

keep if new_time>=0
xtset positive_CAR_announcer new_time
gen cumul_return = Med_R_operat1_wt
replace cumul_return= (1+Med_R_operat1_wt)*(1+L1.Med_R_operat1_wt)-1 if new_time==1
replace cumul_return= (1+Med_R_operat1_wt)*(1+L1.Med_R_operat1_wt)*(1+L2.Med_R_operat1_wt)-1 if new_time==2
replace cumul_return= (1+Med_R_operat1_wt)*(1+L1.Med_R_operat1_wt)*(1+L2.Med_R_operat1_wt)*(1+L3.Med_R_operat1_wt)-1 if new_time==3

gen cumul_return_perc=cumul_return*100

graph twoway line cumul_return_perc new_time if positive_CAR_announcer==1, lwidth(thick) lpattern(solid) lcolor(gs0) ||line cumul_return_perc new_time if positive_CAR_announcer==0, lwidth(thick) lpattern(solid) lcolor(gs7) graphregion(color(white)) bgcolor(white)  legend(lab(1 "Good News") lab (2 "Bad News") region(lcolor(white))) xtitle("Time to Announcement") ytitle("Cumul. Median Op. Performance")
graph export Figure1B_Cumil_op_perf.png, replace




